==> superlinked-12.1.0-py3-none-any.whl: superlinked/framework/common/space/config/embedding/categorical_similarity_embedding_config.py <==
# Copyright 2024 Superlinked, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from beartype.typing import Any, Sequence
from typing_extensions import override

from superlinked.framework.common.space.config.embedding.embedding_config import (
    EmbeddingConfig,
)
from superlinked.framework.common.space.config.embedding.embedding_type import (
    EmbeddingType,
)


class CategoricalSimilarityEmbeddingConfig(EmbeddingConfig[list[str]]):
    def __init__(
        self,
        categories: Sequence[str],
        uncategorized_as_category: bool,
        negative_filter: float = 0.0,
    ) -> None:
        super().__init__(EmbeddingType.CATEGORICAL, list[str])
        self.categories = categories
        self.uncategorized_as_category = uncategorized_as_category
        self.negative_filter = negative_filter

    @property
    @override
    def length(self) -> int:
        return len(self.categories) + 1

    @override
    def to_dict(self) -> dict[str, Any]:
        return super().to_dict() | {
            "categories": self.categories,
            "uncategorized_as_category": self.uncategorized_as_category,
            "negative_filter": self.negative_filter,
        }

==> superlinked-22.3.2-py3-none-any.whl: superlinked/framework/common/space/config/embedding/categorical_similarity_embedding_config.py <==
# Copyright 2024 Superlinked, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from dataclasses import dataclass

from beartype.typing import Any, Sequence
from typing_extensions import override

from superlinked.framework.common.space.config.embedding.embedding_config import (
    EmbeddingConfig,
)


@dataclass(frozen=True)
class CategoricalSimilarityEmbeddingConfig(EmbeddingConfig[list[str]]):
    categories: Sequence[str]
    uncategorized_as_category: bool
    negative_filter: float = 0.0

    @property
    @override
    def length(self) -> int:
        return len(self.categories) + 1

    @override
    def _get_embedding_config_parameters(self) -> dict[str, Any]:
        return {
            "transformation_config": set(self.categories),
            "uncategorized_as_category": self.uncategorized_as_category,
            "negative_filter": self.negative_filter,
        }

    @override
    def __hash__(self) -> int:
        return hash(
            (
                super().__hash__(),
                tuple(self.categories),
                self.uncategorized_as_category,
                self.negative_filter,
            )
        )
